X-Git-Url: https://git.r.bdr.sh/rbdr/r.bdr.sh/blobdiff_plain/a141dd00e8129ba1e75b56cfea96d4cacff0b154..da92cc9956aab1e5970f7806b6cf81a91b994822:/swiftbar/sourcehut-builds.1m.sh?ds=sidebyside
diff --git a/swiftbar/sourcehut-builds.1m.sh b/swiftbar/sourcehut-builds.1m.sh
index 6ad4340..d5d2ae4 100644
--- a/swiftbar/sourcehut-builds.1m.sh
+++ b/swiftbar/sourcehut-builds.1m.sh
@@ -8,15 +8,28 @@
# curl,jq
# https://r.bdr.sh/swiftbar_scripts.html
# string(VAR_SOURCEHUT_API_TOKEN): Your sourcehut API Token.
# number(VAR_BUILD_COUNT=5): How many items to show.
# true
-# VAR_SOURCEHUT_API_TOKEN=no, VAR_BUILD_COUNT=5
+# VAR_SOURCEHUT_API_TOKEN=no, VAR_BUILD_COUNT=9, VAR_RUN_ON_FOCUS=, VAR_HALT_ON_FOCUS=
###############################################################################
# The Variables
###############################################################################
VAR_SOURCEHUT_API_TOKEN=${VAR_SOURCEHUT_API_TOKEN:-'ADD YOUR TOKEN HERE'}
-VAR_BUILD_COUNT=${VAR_BUILD_COUNT:-5}
+VAR_BUILD_COUNT=${VAR_BUILD_COUNT:-10}
+VAR_RUN_ON_FOCUS=
+VAR_HALT_ON_FOCUS=
+
+###############################################################################
+# Focus Check
+###############################################################################
+
+if [[ -f "${BASH_SOURCE%/*}/focus.utils.sh" ]]; then
+ source "${BASH_SOURCE%/*}/focus.utils.sh"
+ focus_check
+fi
###############################################################################
# The Code
@@ -8,15 +8,28 @@
# https://r.bdr.sh/swiftbar_scripts.html
# string(VAR_SOURCEHUT_API_TOKEN): Your sourcehut API Token.
-# number(VAR_BUILD_COUNT=5): How many items to show.
+# number(VAR_BUILD_COUNT=10): How many items to show.
+# string(VAR_RUN_ON_FOCUS): Focus in which to run.
+# string(VAR_HALT_ON_FOCUS): Focus in which to halt.
# true